==> v0.4.0.tar.gz: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/index/query/json/TermJsonFilterBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.query.json;

import org.elasticsearch.util.json.JsonBuilder;

import java.io.IOException;

/**
 * @author kimchy (Shay Banon)
 */
public class TermJsonFilterBuilder extends BaseJsonFilterBuilder {

    private final String name;

    private final Object value;

    public TermJsonFilterBuilder(String name, String value) {
        this(name, (Object) value);
    }

    public TermJsonFilterBuilder(String name, int value) {
        this(name, (Object) value);
    }

    public TermJsonFilterBuilder(String name, long value) {
        this(name, (Object) value);
    }

    public TermJsonFilterBuilder(String name, float value) {
        this(name, (Object) value);
    }

    public TermJsonFilterBuilder(String name, double value) {
        this(name, (Object) value);
    }

    private TermJsonFilterBuilder(String name, Object value) {
        this.name = name;
        this.value = value;
    }

    @Override public void doJson(JsonBuilder builder) throws IOException {
        builder.startObject(TermJsonFilterParser.NAME);
        builder.field(name, value);
        builder.endObject();
    }
}

==> v0.5.1.tar.gz: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/index/query/json/TermJsonFilterBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.query.json;

import org.elasticsearch.util.json.JsonBuilder;

import java.io.IOException;

/**
 * A filter for a field based on a term.
 *
 * @author kimchy (shay.banon)
 */
public class TermJsonFilterBuilder extends BaseJsonFilterBuilder {

    private final String name;

    private final Object value;

    /**
     * A filter for a field based on a term.
     *
     * @param name  The field name
     * @param value The term value
     */
    public TermJsonFilterBuilder(String name, String value) {
        this(name, (Object) value);
    }

    /**
     * A filter for a field based on a term.
     *
     * @param name  The field name
     * @param value The term value
     */
    public TermJsonFilterBuilder(String name, int value) {
        this(name, (Object) value);
    }

    /**
     * A filter for a field based on a term.
     *
     * @param name  The field name
     * @param value The term value
     */
    public TermJsonFilterBuilder(String name, long value) {
        this(name, (Object) value);
    }

    /**
     * A filter for a field based on a term.
     *
     * @param name  The field name
     * @param value The term value
     */
    public TermJsonFilterBuilder(String name, float value) {
        this(name, (Object) value);
    }

    /**
     * A filter for a field based on a term.
     *
     * @param name  The field name
     * @param value The term value
     */
    public TermJsonFilterBuilder(String name, double value) {
        this(name, (Object) value);
    }

    /**
     * A filter for a field based on a term.
     *
     * @param name  The field name
     * @param value The term value
     */
    public TermJsonFilterBuilder(String name, Object value) {
        this.name = name;
        this.value = value;
    }

    @Override public void doJson(JsonBuilder builder, Params params) throws IOException {
        builder.startObject(TermJsonFilterParser.NAME);
        builder.field(name, value);
        builder.endObject();
    }
}
